/*
 * Copyright (c) 2010 David Galindo <nowheremanmail@gmail.com>
 */

#ifndef LOGINDIALOG_H
#define LOGINDIALOG_H


#include <QtGui>
#include <QFileDialog>

class eWallet;
class AboutDialog;

class LoginDialog : public QWidget
{
	Q_OBJECT

public:
	LoginDialog(bool firstTime, eWallet * paTarget);
	~LoginDialog();

	void resetF ();
	void keyPressEvent(QKeyEvent* event);

private slots:
	void select(const QString& a);
	void acceptS();
	void clearS();
	void about();

private:
	QPointer<AboutDialog> aboutDialogDlg;
	QPointer <QMessageBox> messageBox;
	//void focusOutEvent ( QFocusEvent * event );
	QString current;
	QString repeat;
	eWallet * parent;
	
	int NTimes;
	bool isFirstTime;
	QString newPassword;

	QLabel * label;
};
#endif // LOGINDIALOG_H
